PieFedApiV1 class

PieFed API client for API version 1.

Implemented types

Constructors

PieFedApiV1(String host, {String apiPrefix = '/api/alpha', Client? client, Duration timeout = const Duration(seconds: 30)})

Properties

apiPrefix String
final
hashCode int
The hash code for this object.
no setterinherited
host String
The PieFed instance host.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timeout Duration
final

Methods

close() → void
Close the underlying HTTP client.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
run<T>(covariant PieFedApiQuery<T> query) Future<T>
Run an API query.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited