AddMod class

Implemented types
Annotations
  • @freezed

Constructors

AddMod({@JsonKey.new(name: 'community_id') required int communityId, @JsonKey.new(name: 'person_id') required int personId, required bool added, required String auth})
const
factory
AddMod.fromJson(Map<String, dynamic> json)
factory

Properties

added bool
no setterinherited
auth String
no setterinherited
communityId int
no setterinherited
copyWith → $AddModCopyWith<AddMod>
Create a copy of AddMod with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
httpMethod HttpMethod
The HTTP method for this request.
no setteroverride
isMultipart bool
Whether this query contains multipart files.
no setteroverride
multipartFiles List<MultipartFile>?
Optional list of multipart files for the request.
no setteroverride
path String
The API endpoint path (e.g., '/post', '/comment').
no setteroverride
personId int
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
responseFactory(Map<String, dynamic> json) AddModResponse
Deserializes the JSON response into the expected type.
override
toJson() Map<String, dynamic>
Serializes this AddMod to a JSON map.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited