AdminPurgeCommentView class

Annotations
  • @freezed

Constructors

AdminPurgeCommentView({@JsonKey.new(name: 'admin_purge_comment') required AdminPurgeComment adminPurgeComment, Person? admin, required Post post})
const
factory
AdminPurgeCommentView.fromJson(Map<String, dynamic> json)
factory

Properties

admin Person?
no setterinherited
adminPurgeComment AdminPurgeComment
no setterinherited
copyWith → $AdminPurgeCommentViewCopyWith<AdminPurgeCommentView>
Create a copy of AdminPurgeCommentView with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
post Post
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this AdminPurgeCommentView to a JSON map.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited