AdminPurgePersonView class

Annotations
  • @freezed

Constructors

AdminPurgePersonView({@JsonKey.new(name: 'admin_purge_person') required AdminPurgePerson adminPurgePerson, Person? admin})
const
factory
AdminPurgePersonView.fromJson(Map<String, dynamic> json)
factory

Properties

admin Person?
no setterinherited
adminPurgePerson AdminPurgePerson
no setterinherited
copyWith → $AdminPurgePersonViewCopyWith<AdminPurgePersonView>
Create a copy of AdminPurgePersonView with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this AdminPurgePersonView to a JSON map.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited