AdminPurgePost class

Annotations
  • @freezed

Constructors

AdminPurgePost({required int id, @JsonKey.new(name: 'admin_person_id') required int adminPersonId, @JsonKey.new(name: 'community_id') int? communityId, String? reason, @JsonKey.new(name: 'when_') required DateTime when})
const
factory
AdminPurgePost.fromJson(Map<String, dynamic> json)
factory

Properties

adminPersonId int
no setterinherited
communityId int?
no setterinherited
copyWith → $AdminPurgePostCopyWith<AdminPurgePost>
Create a copy of AdminPurgePost with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
id int
no setterinherited
reason String?
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
when DateTime
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this AdminPurgePost to a JSON map.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited