AdminPurgePostView class
- Annotations
-
- @freezed
Constructors
- AdminPurgePostView({@JsonKey.new(name: 'admin_purge_post') required AdminPurgePost adminPurgePost, Person? admin, required Community community})
-
constfactory
-
AdminPurgePostView.fromJson(Map<
String, dynamic> json) -
factory
Properties
- admin → Person?
-
no setterinherited
- adminPurgePost → AdminPurgePost
-
no setterinherited
- community → Community
-
no setterinherited
-
copyWith
→ $AdminPurgePostViewCopyWith<
AdminPurgePostView> -
Create a copy of AdminPurgePostView
with the given fields replaced by the non-null parameter values.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serializes this AdminPurgePostView to a JSON map.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited