AssignPostFlair class
- Implemented types
- Annotations
-
- @freezed
Constructors
-
AssignPostFlair({@JsonKey.new(name: 'post_id') required int postId, @JsonKey.new(name: 'flair_id_list') List<
int> ? flairIdList, required String auth}) -
constfactory
-
AssignPostFlair.fromJson(Map<
String, dynamic> json) -
factory
Properties
- auth → String
-
no setterinherited
-
copyWith
→ $AssignPostFlairCopyWith<
AssignPostFlair> -
Create a copy of AssignPostFlair
with the given fields replaced by the non-null parameter values.
no setterinherited
-
flairIdList
→ List<
int> ? -
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- httpMethod → HttpMethod
-
The HTTP method for this request.
no setteroverride
- isMultipart → bool
-
Whether this query contains multipart files.
no setteroverride
-
multipartFiles
→ List<
MultipartFile> ? -
Optional list of multipart files for the request.
no setteroverride
- path → String
-
The API endpoint path (e.g., '/post', '/comment').
no setteroverride
- postId → int
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
responseFactory(
Map< String, dynamic> json) → PostSetFlairResponse -
Deserializes the JSON response into the expected type.
override
-
toJson(
) → Map< String, dynamic> -
Serializes this AssignPostFlair to a JSON map.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited