BanFromCommunity class

Implemented types
Annotations
  • @freezed

Constructors

BanFromCommunity({@JsonKey.new(name: 'community_id') required int communityId, required String reason, @JsonKey.new(name: 'user_id') required int userId, @JsonKey.new(name: 'expires_at') String? expiresAt, bool? permanent, required String auth})
const
factory
BanFromCommunity.fromJson(Map<String, dynamic> json)
factory

Properties

auth String
no setterinherited
communityId int
no setterinherited
copyWith → $BanFromCommunityCopyWith<BanFromCommunity>
Create a copy of BanFromCommunity with the given fields replaced by the non-null parameter values.
no setterinherited
expiresAt String?
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
httpMethod HttpMethod
The HTTP method for this request.
no setteroverride
isMultipart bool
Whether this query contains multipart files.
no setteroverride
multipartFiles List<MultipartFile>?
Optional list of multipart files for the request.
no setteroverride
path String
The API endpoint path (e.g., '/post', '/comment').
no setteroverride
permanent bool?
no setterinherited
reason String
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
userId int
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
responseFactory(Map<String, dynamic> json) CommunityModerationBanItem
Deserializes the JSON response into the expected type.
override
toJson() Map<String, dynamic>
Serializes this BanFromCommunity to a JSON map.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited