CommentAggregates class

Annotations
  • @freezed

Constructors

CommentAggregates({@JsonKey.new(name: 'comment_id') required int commentId, @Default.new(0) int score, @Default.new(0) int upvotes, @Default.new(0) int downvotes, @JsonKey.new(name: 'child_count') @Default.new(0) int childCount})
const
factory
CommentAggregates.fromJson(Map<String, dynamic> json)
factory

Properties

childCount int
no setterinherited
commentId int
no setterinherited
copyWith → $CommentAggregatesCopyWith<CommentAggregates>
Create a copy of CommentAggregates with the given fields replaced by the non-null parameter values.
no setterinherited
downvotes int
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
score int
no setterinherited
upvotes int
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this CommentAggregates to a JSON map.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited