CommentReply class

Annotations
  • @freezed

Constructors

CommentReply({required int id, @JsonKey.new(name: 'comment_id') required int commentId, required DateTime published, required bool read, @JsonKey.new(name: 'recipient_id') required int recipientId})
const
factory
CommentReply.fromJson(Map<String, dynamic> json)
factory

Properties

commentId int
no setterinherited
copyWith → $CommentReplyCopyWith<CommentReply>
Create a copy of CommentReply with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
id int
no setterinherited
published DateTime
no setterinherited
read bool
no setterinherited
recipientId int
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this CommentReply to a JSON map.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited