CommentReplyView class

Annotations
  • @freezed

Constructors

CommentReplyView({required Comment comment, required Person creator, required Post post, required Community community, @JsonKey.new(name: 'comment_reply') required CommentReply commentReply, CommentAggregates? counts, @JsonKey.new(name: 'activity_alert') bool? activityAlert, required bool saved, @JsonKey.new(name: 'my_vote') int? myVote, @JsonKey.new(fromJson: _subscribedFromJson) SubscribedType? subscribed, bool? distinguished})
const
factory
CommentReplyView.fromJson(Map<String, dynamic> json)
factory

Properties

activityAlert bool?
no setterinherited
comment Comment
no setterinherited
commentReply CommentReply
no setterinherited
community Community
no setterinherited
copyWith → $CommentReplyViewCopyWith<CommentReplyView>
Create a copy of CommentReplyView with the given fields replaced by the non-null parameter values.
no setterinherited
counts CommentAggregates?
no setterinherited
creator Person
no setterinherited
distinguished bool?
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
myVote int?
no setterinherited
post Post
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
saved bool
no setterinherited
subscribed SubscribedType?
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this CommentReplyView to a JSON map.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited