CommentReportView class

Annotations
  • @freezed

Constructors

CommentReportView({@JsonKey.new(name: 'comment_report') required CommentReport commentReport, required Comment comment, required Post post, required Community community, required Person creator, CommentAggregates? counts, @JsonKey.new(name: 'creator_banned_from_community') bool? creatorBannedFromCommunity, @JsonKey.new(name: 'creator_is_moderator') bool? creatorIsModerator, @JsonKey.new(name: 'creator_is_admin') bool? creatorIsAdmin, @JsonKey.new(name: 'creator_blocked') bool? creatorBlocked, @JsonKey.new(name: 'banned_from_community') bool? bannedFromCommunity, @JsonKey.new(name: 'activity_alert') bool? activityAlert, @JsonKey.new(fromJson: _subscribedFromJson) SubscribedType? subscribed, bool? saved, @JsonKey.new(name: 'my_vote') int? myVote, @JsonKey.new(name: 'can_auth_user_moderate') bool? canAuthUserModerate})
const
factory
CommentReportView.fromJson(Map<String, dynamic> json)
factory

Properties

activityAlert bool?
no setterinherited
bannedFromCommunity bool?
no setterinherited
canAuthUserModerate bool?
no setterinherited
comment Comment
no setterinherited
commentReport CommentReport
no setterinherited
community Community
no setterinherited
copyWith → $CommentReportViewCopyWith<CommentReportView>
Create a copy of CommentReportView with the given fields replaced by the non-null parameter values.
no setterinherited
counts CommentAggregates?
no setterinherited
creator Person
no setterinherited
creatorBannedFromCommunity bool?
no setterinherited
creatorBlocked bool?
no setterinherited
creatorIsAdmin bool?
no setterinherited
creatorIsModerator bool?
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
myVote int?
no setterinherited
post Post
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
saved bool?
no setterinherited
subscribed SubscribedType?
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this CommentReportView to a JSON map.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited