Community class

Annotations
  • @freezed

Constructors

Community({required int id, required String name, required String title, @JsonKey.new(name: 'actor_id') required String apId, required bool local, required bool nsfw, required bool deleted, required bool hidden, required bool removed, @JsonKey.new(name: 'instance_id') required int instanceId, @JsonKey.new(name: 'ai_generated', defaultValue: false) required bool aiGenerated, @JsonKey.new(name: 'ap_domain') String? apDomain, @JsonKey.new(name: 'restricted_to_mods') bool? restrictedToMods, bool? banned, @JsonKey.new(name: 'question_answer') bool? questionAnswer, @JsonKey.new(name: 'posting_warning') String? postingWarning, DateTime? updated, String? description, String? icon, String? banner})
const
factory
Community.fromJson(Map<String, dynamic> json)
factory

Properties

aiGenerated bool
no setterinherited
apDomain String?
no setterinherited
apId String
no setterinherited
banned bool?
no setterinherited
no setterinherited
copyWith → $CommunityCopyWith<Community>
Create a copy of Community with the given fields replaced by the non-null parameter values.
no setterinherited
deleted bool
no setterinherited
description String?
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
hidden bool
no setterinherited
icon String?
no setterinherited
id int
no setterinherited
instanceId int
no setterinherited
local bool
no setterinherited
name String
no setterinherited
nsfw bool
no setterinherited
postingWarning String?
no setterinherited
questionAnswer bool?
no setterinherited
removed bool
no setterinherited
restrictedToMods bool?
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String
no setterinherited
updated DateTime?
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this Community to a JSON map.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited