CommunityAggregates class

Annotations
  • @freezed

Constructors

CommunityAggregates({@JsonKey.new(name: 'id') required int id, @JsonKey.new(name: 'post_count') @Default.new(0) int postCount, @JsonKey.new(name: 'post_reply_count') @Default.new(0) int postReplyCount, @JsonKey.new(name: 'subscriptions_count') @Default.new(0) int subscriptionsCount, @JsonKey.new(name: 'total_subscriptions_count') int? totalSubscriptionsCount, @JsonKey.new(name: 'active_daily') @Default.new(0) int activeDaily, @JsonKey.new(name: 'active_weekly') @Default.new(0) int activeWeekly, @JsonKey.new(name: 'active_monthly') @Default.new(0) int activeMonthly, @JsonKey.new(name: 'active_6monthly') @Default.new(0) int active6monthly})
const
factory
CommunityAggregates.fromJson(Map<String, dynamic> json)
factory

Properties

active6monthly int
no setterinherited
activeDaily int
no setterinherited
activeMonthly int
no setterinherited
activeWeekly int
no setterinherited
copyWith → $CommunityAggregatesCopyWith<CommunityAggregates>
Create a copy of CommunityAggregates with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
id int
no setterinherited
postCount int
no setterinherited
postReplyCount int
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subscriptionsCount int
no setterinherited
totalSubscriptionsCount int?
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this CommunityAggregates to a JSON map.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited