CommunityFlairCreateResponse class

Annotations
  • @freezed

Constructors

CommunityFlairCreateResponse({required int id, @JsonKey.new(name: 'community_id') required int communityId, @JsonKey.new(name: 'flair_title') required String flairTitle, @JsonKey.new(name: 'text_color') required String textColor, @JsonKey.new(name: 'background_color') required String backgroundColor, @JsonKey.new(name: 'blur_images') required bool blurImages, @JsonKey.new(name: 'ap_id') String? apId})
const
factory
CommunityFlairCreateResponse.fromJson(Map<String, dynamic> json)
factory

Properties

apId String?
no setterinherited
backgroundColor String
no setterinherited
blurImages bool
no setterinherited
communityId int
no setterinherited
copyWith → $CommunityFlairCreateResponseCopyWith<CommunityFlairCreateResponse>
Create a copy of CommunityFlairCreateResponse with the given fields replaced by the non-null parameter values.
no setterinherited
flairTitle String
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
id int
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
textColor String
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this CommunityFlairCreateResponse to a JSON map.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited