CommunityModerationBanItem class

Annotations
  • @freezed

Constructors

CommunityModerationBanItem({@JsonKey.new(name: 'banned_by') Person? bannedBy, @JsonKey.new(name: 'banned_user') Person? bannedUser, Community? community, bool? expired, @JsonKey.new(name: 'expired_at') String? expiredAt, @JsonKey.new(name: 'expires_at') String? expiresAt, String? reason})
const
factory
CommunityModerationBanItem.fromJson(Map<String, dynamic> json)
factory

Properties

bannedBy Person?
no setterinherited
bannedUser Person?
no setterinherited
community Community?
no setterinherited
copyWith → $CommunityModerationBanItemCopyWith<CommunityModerationBanItem>
Create a copy of CommunityModerationBanItem with the given fields replaced by the non-null parameter values.
no setterinherited
expired bool?
no setterinherited
expiredAt String?
no setterinherited
expiresAt String?
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
reason String?
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this CommunityModerationBanItem to a JSON map.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited