ConversationInfoView class

Annotations
  • @freezed

Constructors

ConversationInfoView({required int id, @Default.new(<Person>[]) List<Person> members, @JsonKey.new(name: 'creator_id') required int creatorId, required DateTime published, required DateTime updated})
const
factory
ConversationInfoView.fromJson(Map<String, dynamic> json)
factory

Properties

copyWith → $ConversationInfoViewCopyWith<ConversationInfoView>
Create a copy of ConversationInfoView with the given fields replaced by the non-null parameter values.
no setterinherited
creatorId int
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
id int
no setterinherited
members List<Person>
no setterinherited
published DateTime
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
updated DateTime
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this ConversationInfoView to a JSON map.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited