ConversationReport class

Annotations
  • @freezed

Constructors

ConversationReport({required int id, @JsonKey.new(name: 'creator_id') required int creatorId, @JsonKey.new(name: 'conversation_id') required int conversationId, required String? reason, required String? description, required bool resolved, required DateTime published})
const
factory
ConversationReport.fromJson(Map<String, dynamic> json)
factory

Properties

conversationId int
no setterinherited
copyWith → $ConversationReportCopyWith<ConversationReport>
Create a copy of ConversationReport with the given fields replaced by the non-null parameter values.
no setterinherited
creatorId int
no setterinherited
description String?
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
id int
no setterinherited
published DateTime
no setterinherited
reason String?
no setterinherited
resolved bool
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this ConversationReport to a JSON map.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited