CreateComment class

Implemented types
Annotations
  • @freezed

Constructors

CreateComment({required String body, @JsonKey.new(name: 'post_id') required int postId, @JsonKey.new(name: 'parent_id') int? parentId, @JsonKey.new(name: 'language_id') int? languageId, required String auth, @Default.new(false) bool answer})
const
factory
CreateComment.fromJson(Map<String, dynamic> json)
factory

Properties

answer bool
no setterinherited
auth String
no setterinherited
body String
no setterinherited
copyWith → $CreateCommentCopyWith<CreateComment>
Create a copy of CreateComment with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
httpMethod HttpMethod
The HTTP method for this request.
no setteroverride
isMultipart bool
Whether this query contains multipart files.
no setteroverride
languageId int?
no setterinherited
multipartFiles List<MultipartFile>?
Optional list of multipart files for the request.
no setteroverride
parentId int?
no setterinherited
path String
The API endpoint path (e.g., '/post', '/comment').
no setteroverride
postId int
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
responseFactory(Map<String, dynamic> json) GetCommentResponse
Deserializes the JSON response into the expected type.
override
toJson() Map<String, dynamic>
Serializes this CreateComment to a JSON map.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited