EditCommunityFlair class

Implemented types
Annotations
  • @freezed

Constructors

EditCommunityFlair({@JsonKey.new(name: 'flair_id') required int flairId, @JsonKey.new(name: 'flair_title') String? flairTitle, @JsonKey.new(name: 'text_color') String? textColor, @JsonKey.new(name: 'background_color') String? backgroundColor, @JsonKey.new(name: 'blur_images') bool? blurImages, required String auth})
const
factory
EditCommunityFlair.fromJson(Map<String, dynamic> json)
factory

Properties

auth String
no setterinherited
backgroundColor String?
no setterinherited
blurImages bool?
no setterinherited
copyWith → $EditCommunityFlairCopyWith<EditCommunityFlair>
Create a copy of EditCommunityFlair with the given fields replaced by the non-null parameter values.
no setterinherited
flairId int
no setterinherited
flairTitle String?
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
httpMethod HttpMethod
The HTTP method for this request.
no setteroverride
isMultipart bool
Whether this query contains multipart files.
no setteroverride
multipartFiles List<MultipartFile>?
Optional list of multipart files for the request.
no setteroverride
path String
The API endpoint path (e.g., '/post', '/comment').
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
textColor String?
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
responseFactory(Map<String, dynamic> json) CommunityFlairEditResponse
Deserializes the JSON response into the expected type.
override
toJson() Map<String, dynamic>
Serializes this EditCommunityFlair to a JSON map.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited