EditFeed class

Implemented types
Annotations
  • @freezed

Constructors

EditFeed({@JsonKey.new(name: 'feed_id') required int feedId, String? url, String? title, String? description, @JsonKey.new(name: 'icon_url') String? iconUrl, @JsonKey.new(name: 'banner_url') String? bannerUrl, bool? nsfw, bool? nsfl, bool? public, String? communities, @JsonKey.new(name: 'is_instance_feed') bool? isInstanceFeed, @JsonKey.new(name: 'show_child_posts') bool? showChildPosts, @JsonKey.new(name: 'parent_feed_id') int? parentFeedId, required String auth})
const
factory
EditFeed.fromJson(Map<String, dynamic> json)
factory

Properties

auth String
no setterinherited
bannerUrl String?
no setterinherited
communities String?
no setterinherited
copyWith → $EditFeedCopyWith<EditFeed>
Create a copy of EditFeed with the given fields replaced by the non-null parameter values.
no setterinherited
description String?
no setterinherited
feedId int
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
httpMethod HttpMethod
The HTTP method for this request.
no setteroverride
iconUrl String?
no setterinherited
isInstanceFeed bool?
no setterinherited
isMultipart bool
Whether this query contains multipart files.
no setteroverride
multipartFiles List<MultipartFile>?
Optional list of multipart files for the request.
no setteroverride
nsfl bool?
no setterinherited
nsfw bool?
no setterinherited
parentFeedId int?
no setterinherited
path String
The API endpoint path (e.g., '/post', '/comment').
no setteroverride
public bool?
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showChildPosts bool?
no setterinherited
title String?
no setterinherited
url String?
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
responseFactory(Map<String, dynamic> json) GetFeedResponse
Deserializes the JSON response into the expected type.
override
toJson() Map<String, dynamic>
Serializes this EditFeed to a JSON map.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited