FederatedInstancesView class

Annotations
  • @freezed

Constructors

FederatedInstancesView({required List<Instance> allowed, required List<Instance> blocked, required List<Instance> linked})
const
factory
FederatedInstancesView.fromJson(Map<String, dynamic> json)
factory

Properties

allowed List<Instance>
no setterinherited
blocked List<Instance>
no setterinherited
copyWith → $FederatedInstancesViewCopyWith<FederatedInstancesView>
Create a copy of FederatedInstancesView with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
linked List<Instance>
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this FederatedInstancesView to a JSON map.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited