FeedView class
- Annotations
-
- @freezed
Constructors
-
FeedView({required int id, required String name, required String title, String? description, @JsonKey.new(name: 'actor_id') required String actorId, @JsonKey.new(name: 'ap_domain') required String apDomain, required bool local, @JsonKey.new(name: 'is_instance_feed') required bool isInstanceFeed, @JsonKey.new(name: 'communities_count') required int communitiesCount, required List<
Community> communities, required List<FeedView> children}) -
constfactory
-
FeedView.fromJson(Map<
String, dynamic> json) -
factory
Properties
- actorId → String
-
no setterinherited
- apDomain → String
-
no setterinherited
-
children
→ List<
FeedView> -
no setterinherited
-
communities
→ List<
Community> -
no setterinherited
- communitiesCount → int
-
no setterinherited
-
copyWith
→ $FeedViewCopyWith<
FeedView> -
Create a copy of FeedView
with the given fields replaced by the non-null parameter values.
no setterinherited
- description → String?
-
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → int
-
no setterinherited
- isInstanceFeed → bool
-
no setterinherited
- local → bool
-
no setterinherited
- name → String
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- title → String
-
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serializes this FeedView to a JSON map.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited