FetchCaptchaResponse class

Annotations
  • @freezed

Constructors

FetchCaptchaResponse({List<CaptchaFields>? ok})
const
factory
FetchCaptchaResponse.fromJson(Map<String, dynamic> json)
factory

Properties

copyWith → $FetchCaptchaResponseCopyWith<FetchCaptchaResponse>
Create a copy of FetchCaptchaResponse with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
ok List<CaptchaFields>?
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this FetchCaptchaResponse to a JSON map.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited