GetComment class

Implemented types
Annotations
  • @freezed

Constructors

GetComment({required int id, String? auth})
const
factory
GetComment.fromJson(Map<String, dynamic> json)
factory

Properties

auth String?
no setterinherited
copyWith → $GetCommentCopyWith<GetComment>
Create a copy of GetComment with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
httpMethod HttpMethod
The HTTP method for this request.
no setteroverride
id int
no setterinherited
isMultipart bool
Whether this query contains multipart files.
no setteroverride
multipartFiles List<MultipartFile>?
Optional list of multipart files for the request.
no setteroverride
path String
The API endpoint path (e.g., '/post', '/comment').
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
responseFactory(Map<String, dynamic> json) GetCommentResponse
Deserializes the JSON response into the expected type.
override
toJson() Map<String, dynamic>
Serializes this GetComment to a JSON map.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited