GetCommentResponse class

Annotations
  • @freezed

Constructors

GetCommentResponse({@JsonKey.new(name: 'comment_view') required CommentView commentView})
const
factory
GetCommentResponse.fromJson(Map<String, dynamic> json)
factory

Properties

commentView CommentView
no setterinherited
copyWith → $GetCommentResponseCopyWith<GetCommentResponse>
Create a copy of GetCommentResponse with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this GetCommentResponse to a JSON map.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited