GetConversationReportListResponse class

Annotations
  • @freezed

Constructors

GetConversationReportListResponse({@JsonKey.new(name: 'conversation_reports') required List<ConversationReportView> conversationReports, @JsonKey.new(name: 'next_page') String? nextPage})
const
factory
GetConversationReportListResponse.fromJson(Map<String, dynamic> json)
factory

Properties

conversationReports List<ConversationReportView>
no setterinherited
copyWith → $GetConversationReportListResponseCopyWith<GetConversationReportListResponse>
Create a copy of GetConversationReportListResponse with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
nextPage String?
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this GetConversationReportListResponse to a JSON map.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited