GetModLog class

Implemented types
Annotations
  • @freezed

Constructors

GetModLog({@JsonKey.new(name: 'mod_person_id') int? modPersonId, @JsonKey.new(name: 'community_id') int? communityId, int? page, int? limit, @JsonKey.new(name: 'type_') ModLogType? type, @JsonKey.new(name: 'other_person_id') int? otherPersonId, @JsonKey.new(name: 'post_id') int? postId, @JsonKey.new(name: 'comment_id') int? commentId, String? auth})
const
factory
GetModLog.fromJson(Map<String, dynamic> json)
factory

Properties

auth String?
no setterinherited
commentId int?
no setterinherited
communityId int?
no setterinherited
copyWith → $GetModLogCopyWith<GetModLog>
Create a copy of GetModLog with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
httpMethod HttpMethod
The HTTP method for this request.
no setteroverride
isMultipart bool
Whether this query contains multipart files.
no setteroverride
limit int?
no setterinherited
modPersonId int?
no setterinherited
multipartFiles List<MultipartFile>?
Optional list of multipart files for the request.
no setteroverride
otherPersonId int?
no setterinherited
page int?
no setterinherited
path String
The API endpoint path (e.g., '/post', '/comment').
no setteroverride
postId int?
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type ModLogType?
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
responseFactory(Map<String, dynamic> json) GetModLogResponse
Deserializes the JSON response into the expected type.
override
toJson() Map<String, dynamic>
Serializes this GetModLog to a JSON map.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited