GetPersonDetails class
- Implemented types
- Annotations
-
- @freezed
Constructors
- GetPersonDetails({@JsonKey.new(name: 'person_id') int? personId, String? username, String? auth, String? sort, int? page, int? limit, @JsonKey.new(name: 'community_id') int? communityId, @JsonKey.new(name: 'saved_only') bool? savedOnly, @JsonKey.new(name: 'include_content') bool? includeContent})
-
constfactory
-
GetPersonDetails.fromJson(Map<
String, dynamic> json) -
factory
Properties
- auth → String?
-
no setterinherited
- communityId → int?
-
no setterinherited
-
copyWith
→ $GetPersonDetailsCopyWith<
GetPersonDetails> -
Create a copy of GetPersonDetails
with the given fields replaced by the non-null parameter values.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- httpMethod → HttpMethod
-
The HTTP method for this request.
no setteroverride
- includeContent → bool?
-
no setterinherited
- isMultipart → bool
-
Whether this query contains multipart files.
no setteroverride
- limit → int?
-
no setterinherited
-
multipartFiles
→ List<
MultipartFile> ? -
Optional list of multipart files for the request.
no setteroverride
- page → int?
-
no setterinherited
- path → String
-
The API endpoint path (e.g., '/post', '/comment').
no setteroverride
- personId → int?
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- savedOnly → bool?
-
no setterinherited
- sort → String?
-
no setterinherited
- username → String?
-
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
responseFactory(
Map< String, dynamic> json) → GetPersonDetailsResponse -
Deserializes the JSON response into the expected type.
override
-
toJson(
) → Map< String, dynamic> -
Serializes this GetPersonDetails to a JSON map.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited