GetPersonDetailsResponse class

Annotations
  • @freezed

Constructors

GetPersonDetailsResponse({@JsonKey.new(name: 'person_view') required PersonView personView, required List<CommentView> comments, required List<PostView> posts})
const
factory
GetPersonDetailsResponse.fromJson(Map<String, dynamic> json)
factory

Properties

comments List<CommentView>
no setterinherited
copyWith → $GetPersonDetailsResponseCopyWith<GetPersonDetailsResponse>
Create a copy of GetPersonDetailsResponse with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
personView PersonView
no setterinherited
posts List<PostView>
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this GetPersonDetailsResponse to a JSON map.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited