GetPostLikesResponse class

Annotations
  • @freezed

Constructors

GetPostLikesResponse({@JsonKey.new(name: 'post_likes') required List<PersonView> postLikes})
const
factory
GetPostLikesResponse.fromJson(Map<String, dynamic> json)
factory

Properties

copyWith → $GetPostLikesResponseCopyWith<GetPostLikesResponse>
Create a copy of GetPostLikesResponse with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
postLikes List<PersonView>
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this GetPostLikesResponse to a JSON map.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited