GetPostResponse class
- Annotations
-
- @freezed
Constructors
-
GetPostResponse({@JsonKey.new(name: 'post_view') required PostView postView, @JsonKey.new(name: 'community_view') CommunityView? communityView, List<
CommunityModeratorView> ? moderators, @JsonKey.new(name: 'cross_posts') List<PostView> ? crossPosts}) -
constfactory
-
GetPostResponse.fromJson(Map<
String, dynamic> json) -
factory
Properties
- communityView → CommunityView?
-
no setterinherited
-
copyWith
→ $GetPostResponseCopyWith<
GetPostResponse> -
Create a copy of GetPostResponse
with the given fields replaced by the non-null parameter values.
no setterinherited
-
crossPosts
→ List<
PostView> ? -
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
-
moderators
→ List<
CommunityModeratorView> ? -
no setterinherited
- postView → PostView
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serializes this GetPostResponse to a JSON map.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited