GetSiteResponse class

Annotations
  • @freezed

Constructors

GetSiteResponse({required Site site, required List<PersonView> admins, required String version, @JsonKey.new(name: 'my_user') MyUserInfo? myUser})
const
factory
GetSiteResponse.fromJson(Map<String, dynamic> json)
factory

Properties

admins List<PersonView>
no setterinherited
copyWith → $GetSiteResponseCopyWith<GetSiteResponse>
Create a copy of GetSiteResponse with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
myUser MyUserInfo?
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
site Site
no setterinherited
version String
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this GetSiteResponse to a JSON map.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited