GetUnreadCountResponse class

Annotations
  • @freezed

Constructors

GetUnreadCountResponse({@JsonKey.new(name: 'replies') @Default.new(0) int replies, @JsonKey.new(name: 'mentions') @Default.new(0) int mentions, @JsonKey.new(name: 'private_messages') @Default.new(0) int privateMessages})
const
factory
GetUnreadCountResponse.fromJson(Map<String, dynamic> json)
factory

Properties

copyWith → $GetUnreadCountResponseCopyWith<GetUnreadCountResponse>
Create a copy of GetUnreadCountResponse with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
mentions int
no setterinherited
privateMessages int
no setterinherited
replies int
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this GetUnreadCountResponse to a JSON map.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited