ImageDeleteResponse class

Annotations
  • @freezed

Constructors

ImageDeleteResponse({String? result})
const
factory
ImageDeleteResponse.fromJson(Map<String, dynamic> json)
factory

Properties

copyWith → $ImageDeleteResponseCopyWith<ImageDeleteResponse>
Create a copy of ImageDeleteResponse with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
result String?
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this ImageDeleteResponse to a JSON map.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited