ImageUploadResponse class

Annotations
  • @freezed

Constructors

ImageUploadResponse({String? url, @JsonKey.new(name: 'liked_only') bool? likedOnly, @JsonKey.new(name: 'saved_only') bool? savedOnly, String? q})
const
factory
ImageUploadResponse.fromJson(Map<String, dynamic> json)
factory

Properties

copyWith → $ImageUploadResponseCopyWith<ImageUploadResponse>
Create a copy of ImageUploadResponse with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
likedOnly bool?
no setterinherited
q String?
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
savedOnly bool?
no setterinherited
url String?
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this ImageUploadResponse to a JSON map.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited