Instance class

Annotations
  • @freezed

Constructors

Instance({required int id, required String domain, required DateTime published, String? software, String? version})
const
factory
Instance.fromJson(Map<String, dynamic> json)
factory

Properties

copyWith → $InstanceCopyWith<Instance>
Create a copy of Instance with the given fields replaced by the non-null parameter values.
no setterinherited
domain String
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
id int
no setterinherited
published DateTime
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
software String?
no setterinherited
version String?
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this Instance to a JSON map.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited