InstanceBlockView class
Properties
-
copyWith
→ $InstanceBlockViewCopyWith<InstanceBlockView>
-
Create a copy of InstanceBlockView
with the given fields replaced by the non-null parameter values.
no setterinherited
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
instance
→ Instance
-
no setterinherited
-
person
→ Person
-
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson()
→ Map<String, dynamic>
-
Serializes this InstanceBlockView to a JSON map.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited