ListCommentLikesResponse class

Annotations
  • @freezed

Constructors

ListCommentLikesResponse({@JsonKey.new(name: 'comment_likes') required List<CommentLikeView> commentLikes, @JsonKey.new(name: 'next_page') String? nextPage})
const
factory
ListCommentLikesResponse.fromJson(Map<String, dynamic> json)
factory

Properties

commentLikes List<CommentLikeView>
no setterinherited
copyWith → $ListCommentLikesResponseCopyWith<ListCommentLikesResponse>
Create a copy of ListCommentLikesResponse with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
nextPage String?
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this ListCommentLikesResponse to a JSON map.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited