ListComments class
Query to list comments with various filters.
- Implemented types
- Annotations
-
- @freezed
Constructors
- ListComments({int? limit, int? page, String? sort, @JsonKey.new(name: 'type_') String? type, @JsonKey.new(name: 'community_id') int? communityId, @JsonKey.new(name: 'community_name') String? communityName, @JsonKey.new(name: 'post_id') int? postId, @JsonKey.new(name: 'parent_id') int? parentId, @JsonKey.new(name: 'max_depth') int? maxDepth, @JsonKey.new(name: 'depth_first') bool? depthFirst, @JsonKey.new(name: 'saved_only') bool? savedOnly, @JsonKey.new(name: 'liked_only') bool? likedOnly, @JsonKey.new(name: 'person_id') int? personId, String? auth})
-
constfactory
-
ListComments.fromJson(Map<
String, dynamic> json) -
factory
Properties
- auth → String?
-
no setterinherited
- communityId → int?
-
no setterinherited
- communityName → String?
-
no setterinherited
-
copyWith
→ $ListCommentsCopyWith<
ListComments> -
Create a copy of ListComments
with the given fields replaced by the non-null parameter values.
no setterinherited
- depthFirst → bool?
-
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- httpMethod → HttpMethod
-
The HTTP method for this request.
no setteroverride
- isMultipart → bool
-
Whether this query contains multipart files.
no setteroverride
- likedOnly → bool?
-
no setterinherited
- limit → int?
-
no setterinherited
- maxDepth → int?
-
no setterinherited
-
multipartFiles
→ List<
MultipartFile> ? -
Optional list of multipart files for the request.
no setteroverride
- page → int?
-
no setterinherited
- parentId → int?
-
no setterinherited
- path → String
-
The API endpoint path (e.g., '/post', '/comment').
no setteroverride
- personId → int?
-
no setterinherited
- postId → int?
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- savedOnly → bool?
-
no setterinherited
- sort → String?
-
no setterinherited
- type → String?
-
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
responseFactory(
Map< String, dynamic> json) → ListCommentsResponse -
Deserializes the JSON response into the expected type.
override
-
toJson(
) → Map< String, dynamic> -
Serializes this ListComments to a JSON map.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited