ListCommunitiesResponse class
- Annotations
-
- @freezed
Constructors
-
ListCommunitiesResponse({required List<
CommunityView> communities}) -
constfactory
-
ListCommunitiesResponse.fromJson(Map<
String, dynamic> json) -
factory
Properties
-
communities
→ List<
CommunityView> -
no setterinherited
-
copyWith
→ $ListCommunitiesResponseCopyWith<
ListCommunitiesResponse> -
Create a copy of ListCommunitiesResponse
with the given fields replaced by the non-null parameter values.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serializes this ListCommunitiesResponse to a JSON map.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited