ListConversationReports class
- Implemented types
- Annotations
-
- @freezed
Constructors
- ListConversationReports({@JsonKey.new(name: 'conversation_id') int? conversationId, int? limit, int? page, @JsonKey.new(name: 'unresolved_only') bool? unresolvedOnly, @JsonKey.new(name: 'message_history_limit') int? messageHistoryLimit, required String auth})
-
constfactory
-
ListConversationReports.fromJson(Map<
String, dynamic> json) -
factory
Properties
- auth → String
-
no setterinherited
- conversationId → int?
-
no setterinherited
-
copyWith
→ $ListConversationReportsCopyWith<
ListConversationReports> -
Create a copy of ListConversationReports
with the given fields replaced by the non-null parameter values.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- httpMethod → HttpMethod
-
The HTTP method for this request.
no setteroverride
- isMultipart → bool
-
Whether this query contains multipart files.
no setteroverride
- limit → int?
-
no setterinherited
- messageHistoryLimit → int?
-
no setterinherited
-
multipartFiles
→ List<
MultipartFile> ? -
Optional list of multipart files for the request.
no setteroverride
- page → int?
-
no setterinherited
- path → String
-
The API endpoint path (e.g., '/post', '/comment').
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- unresolvedOnly → bool?
-
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
responseFactory(
Map< String, dynamic> json) → GetConversationReportListResponse -
Deserializes the JSON response into the expected type.
override
-
toJson(
) → Map< String, dynamic> -
Serializes this ListConversationReports to a JSON map.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited