ListPostReports class

Implemented types
Annotations
  • @freezed

Constructors

ListPostReports({@JsonKey.new(name: 'community_id') int? communityId, int? limit, int? page, @JsonKey.new(name: 'post_id') int? postId, @JsonKey.new(name: 'unresolved_only') bool? unresolvedOnly, required String auth})
const
factory
ListPostReports.fromJson(Map<String, dynamic> json)
factory

Properties

auth String
no setterinherited
communityId int?
no setterinherited
copyWith → $ListPostReportsCopyWith<ListPostReports>
Create a copy of ListPostReports with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
httpMethod HttpMethod
The HTTP method for this request.
no setteroverride
isMultipart bool
Whether this query contains multipart files.
no setteroverride
limit int?
no setterinherited
multipartFiles List<MultipartFile>?
Optional list of multipart files for the request.
no setteroverride
page int?
no setterinherited
path String
The API endpoint path (e.g., '/post', '/comment').
no setteroverride
postId int?
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
unresolvedOnly bool?
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
responseFactory(Map<String, dynamic> json) GetPostReportListResponse
Deserializes the JSON response into the expected type.
override
toJson() Map<String, dynamic>
Serializes this ListPostReports to a JSON map.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited