LocalUser class

Annotations
  • @freezed

Constructors

LocalUser({@JsonKey.new(name: 'accept_private_messages') required String acceptPrivateMessages, @JsonKey.new(name: 'bot_visibility') required String botVisibility, @JsonKey.new(name: 'ai_visibility') required String aiVisibility, @JsonKey.new(name: 'community_keyword_filter') List<String>? communityKeywordFilter, @JsonKey.new(name: 'default_comment_sort_type') required String defaultCommentSortType, @JsonKey.new(name: 'default_listing_type') required String defaultListingType, @JsonKey.new(name: 'default_sort_type') String? defaultSortType, @JsonKey.new(name: 'email_unread') required bool emailUnread, @JsonKey.new(name: 'federate_votes') required bool federateVotes, @JsonKey.new(name: 'feed_auto_follow') required bool feedAutoFollow, @JsonKey.new(name: 'feed_auto_leave') required bool feedAutoLeave, @JsonKey.new(name: 'hide_low_quality') required bool hideLowQuality, required bool indexable, required bool newsletter, @JsonKey.new(name: 'nsfl_visibility') required String nsflVisibility, @JsonKey.new(name: 'nsfw_visibility') required String nsfwVisibility, @JsonKey.new(name: 'reply_collapse_threshold') required int replyCollapseThreshold, @JsonKey.new(name: 'reply_hide_threshold') required int replyHideThreshold, required bool searchable, @JsonKey.new(name: 'show_bot_accounts') required bool showBotAccounts, @JsonKey.new(name: 'show_nsfl') required bool showNsfl, @JsonKey.new(name: 'show_nsfw') required bool showNsfw, @JsonKey.new(name: 'show_read_posts') required bool showReadPosts, @JsonKey.new(name: 'show_scores') required bool showScores})
const
factory
LocalUser.fromJson(Map<String, dynamic> json)
factory

Properties

acceptPrivateMessages String
no setterinherited
aiVisibility String
no setterinherited
botVisibility String
no setterinherited
communityKeywordFilter List<String>?
no setterinherited
copyWith → $LocalUserCopyWith<LocalUser>
Create a copy of LocalUser with the given fields replaced by the non-null parameter values.
no setterinherited
defaultCommentSortType String
no setterinherited
defaultListingType String
no setterinherited
defaultSortType String?
no setterinherited
emailUnread bool
no setterinherited
federateVotes bool
no setterinherited
feedAutoFollow bool
no setterinherited
feedAutoLeave bool
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
hideLowQuality bool
no setterinherited
indexable bool
no setterinherited
newsletter bool
no setterinherited
nsflVisibility String
no setterinherited
nsfwVisibility String
no setterinherited
replyCollapseThreshold int
no setterinherited
replyHideThreshold int
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
searchable bool
no setterinherited
showBotAccounts bool
no setterinherited
showNsfl bool
no setterinherited
showNsfw bool
no setterinherited
showReadPosts bool
no setterinherited
showScores bool
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this LocalUser to a JSON map.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited