MiniCrossPosts class

Annotations
  • @freezed

Constructors

MiniCrossPosts({@JsonKey.new(name: 'post_id') required int postId, @JsonKey.new(name: 'reply_count') required int replyCount, @JsonKey.new(name: 'community_name') required String communityName})
const
factory
MiniCrossPosts.fromJson(Map<String, dynamic> json)
factory

Properties

communityName String
no setterinherited
copyWith → $MiniCrossPostsCopyWith<MiniCrossPosts>
Create a copy of MiniCrossPosts with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
postId int
no setterinherited
replyCount int
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this MiniCrossPosts to a JSON map.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited