ModAdd class

Annotations
  • @freezed

Constructors

ModAdd({required int id, @JsonKey.new(name: 'mod_person_id') int? modPersonId, @JsonKey.new(name: 'other_person_id') int? otherPersonId, required bool removed, @JsonKey.new(name: 'when_') required DateTime when})
const
factory
ModAdd.fromJson(Map<String, dynamic> json)
factory

Properties

copyWith → $ModAddCopyWith<ModAdd>
Create a copy of ModAdd with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
id int
no setterinherited
modPersonId int?
no setterinherited
otherPersonId int?
no setterinherited
removed bool
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
when DateTime
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this ModAdd to a JSON map.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited