ModAddCommunityView class

Annotations
  • @freezed

Constructors

ModAddCommunityView({@JsonKey.new(name: 'mod_add_community') required ModAddCommunity modAddCommunity, Person? moderator, Community? community, @JsonKey.new(name: 'modded_person') Person? moddedPerson})
const
factory
ModAddCommunityView.fromJson(Map<String, dynamic> json)
factory

Properties

community Community?
no setterinherited
copyWith → $ModAddCommunityViewCopyWith<ModAddCommunityView>
Create a copy of ModAddCommunityView with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
modAddCommunity ModAddCommunity
no setterinherited
moddedPerson Person?
no setterinherited
moderator Person?
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this ModAddCommunityView to a JSON map.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited