ModBan class

Annotations
  • @freezed

Constructors

ModBan({required int id, @JsonKey.new(name: 'mod_person_id') int? modPersonId, @JsonKey.new(name: 'other_person_id') int? otherPersonId, String? reason, required bool banned, DateTime? expires, @JsonKey.new(name: 'when_') required DateTime when})
const
factory
ModBan.fromJson(Map<String, dynamic> json)
factory

Properties

banned bool
no setterinherited
copyWith → $ModBanCopyWith<ModBan>
Create a copy of ModBan with the given fields replaced by the non-null parameter values.
no setterinherited
expires DateTime?
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
id int
no setterinherited
modPersonId int?
no setterinherited
otherPersonId int?
no setterinherited
reason String?
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
when DateTime
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this ModBan to a JSON map.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited