ModBanFromCommunityView class

Annotations
  • @freezed

Constructors

ModBanFromCommunityView({@JsonKey.new(name: 'mod_ban_from_community') required ModBanFromCommunity modBanFromCommunity, Person? moderator, Community? community, @JsonKey.new(name: 'banned_person') Person? bannedPerson})
const
factory
ModBanFromCommunityView.fromJson(Map<String, dynamic> json)
factory

Properties

bannedPerson Person?
no setterinherited
community Community?
no setterinherited
copyWith → $ModBanFromCommunityViewCopyWith<ModBanFromCommunityView>
Create a copy of ModBanFromCommunityView with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
modBanFromCommunity ModBanFromCommunity
no setterinherited
moderator Person?
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this ModBanFromCommunityView to a JSON map.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited