ModFeaturePost class

Annotations
  • @freezed

Constructors

ModFeaturePost({required int id, @JsonKey.new(name: 'mod_person_id') int? modPersonId, @JsonKey.new(name: 'post_id') int? postId, required bool featured, @JsonKey.new(name: 'is_featured_community') required bool isFeaturedCommunity, @JsonKey.new(name: 'when_') required DateTime when})
const
factory
ModFeaturePost.fromJson(Map<String, dynamic> json)
factory

Properties

copyWith → $ModFeaturePostCopyWith<ModFeaturePost>
Create a copy of ModFeaturePost with the given fields replaced by the non-null parameter values.
no setterinherited
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
id int
no setterinherited
isFeaturedCommunity bool
no setterinherited
modPersonId int?
no setterinherited
postId int?
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
when DateTime
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this ModFeaturePost to a JSON map.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited