ModHideCommunity class

Annotations
  • @freezed

Constructors

ModHideCommunity({required int id, @JsonKey.new(name: 'community_id') int? communityId, @JsonKey.new(name: 'mod_person_id') int? modPersonId, String? reason, required bool hidden, @JsonKey.new(name: 'when_') required DateTime when})
const
factory
ModHideCommunity.fromJson(Map<String, dynamic> json)
factory

Properties

communityId int?
no setterinherited
copyWith → $ModHideCommunityCopyWith<ModHideCommunity>
Create a copy of ModHideCommunity with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
hidden bool
no setterinherited
id int
no setterinherited
modPersonId int?
no setterinherited
reason String?
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
when DateTime
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this ModHideCommunity to a JSON map.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited