ModHideCommunityView class

Annotations
  • @freezed

Constructors

ModHideCommunityView({@JsonKey.new(name: 'mod_hide_community') required ModHideCommunity modHideCommunity, Person? admin, required Community community})
const
factory
ModHideCommunityView.fromJson(Map<String, dynamic> json)
factory

Properties

admin Person?
no setterinherited
community Community
no setterinherited
copyWith → $ModHideCommunityViewCopyWith<ModHideCommunityView>
Create a copy of ModHideCommunityView with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
modHideCommunity ModHideCommunity
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this ModHideCommunityView to a JSON map.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited