ModRemoveCommentView class
Constructors
-
const
factory
-
factory
Properties
-
no setterinherited
-
no setterinherited
-
no setterinherited
-
copyWith
→ $ModRemoveCommentViewCopyWith<ModRemoveCommentView>
-
Create a copy of ModRemoveCommentView
with the given fields replaced by the non-null parameter values.
no setterinherited
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
moderator
→ Person?
-
no setterinherited
-
no setterinherited
-
post
→ Post?
-
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson()
→ Map<String, dynamic>
-
Serializes this ModRemoveCommentView to a JSON map.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited