ModRemoveCommunity class
Constructors
-
const
factory
-
factory
Properties
-
no setterinherited
-
copyWith
→ $ModRemoveCommunityCopyWith<ModRemoveCommunity>
-
Create a copy of ModRemoveCommunity
with the given fields replaced by the non-null parameter values.
no setterinherited
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
id
→ int
-
no setterinherited
-
modPersonId
→ int?
-
no setterinherited
-
reason
→ String?
-
no setterinherited
-
removed
→ bool
-
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
-
when
→ DateTime
-
no setterinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson()
→ Map<String, dynamic>
-
Serializes this ModRemoveCommunity to a JSON map.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited