ModRemoveCommunityView class

Annotations
  • @freezed

Constructors

ModRemoveCommunityView({@JsonKey.new(name: 'mod_remove_community') required ModRemoveCommunity modRemoveCommunity, Person? moderator, Community? community})
const
factory
ModRemoveCommunityView.fromJson(Map<String, dynamic> json)
factory

Properties

community Community?
no setterinherited
copyWith → $ModRemoveCommunityViewCopyWith<ModRemoveCommunityView>
Create a copy of ModRemoveCommunityView with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
moderator Person?
no setterinherited
modRemoveCommunity ModRemoveCommunity
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this ModRemoveCommunityView to a JSON map.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited