ModTransferCommunityView class

Annotations
  • @freezed

Constructors

ModTransferCommunityView({@JsonKey.new(name: 'mod_transfer_community') required ModTransferCommunity modTransferCommunity, Person? moderator, required Community community, @JsonKey.new(name: 'modded_person') Person? moddedPerson})
const
factory
ModTransferCommunityView.fromJson(Map<String, dynamic> json)
factory

Properties

community Community
no setterinherited
copyWith → $ModTransferCommunityViewCopyWith<ModTransferCommunityView>
Create a copy of ModTransferCommunityView with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
moddedPerson Person?
no setterinherited
moderator Person?
no setterinherited
modTransferCommunity ModTransferCommunity
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this ModTransferCommunityView to a JSON map.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited