MyUserInfo class
- Annotations
-
- @freezed
Constructors
-
MyUserInfo({@JsonKey.new(name: 'community_blocks') required List<
CommunityBlockView> communityBlocks, @JsonKey.new(name: 'discussion_languages') required List<LanguageView> discussionLanguages, required List<CommunityFollowerView> follows, @JsonKey.new(name: 'instance_blocks') required List<InstanceBlockView> instanceBlocks, @JsonKey.new(name: 'local_user_view') required LocalUserView localUserView, required List<CommunityModeratorView> moderates, @JsonKey.new(name: 'person_blocks') required List<PersonBlockView> personBlocks}) -
constfactory
-
MyUserInfo.fromJson(Map<
String, dynamic> json) -
factory
Properties
-
communityBlocks
→ List<
CommunityBlockView> -
no setterinherited
-
copyWith
→ $MyUserInfoCopyWith<
MyUserInfo> -
Create a copy of MyUserInfo
with the given fields replaced by the non-null parameter values.
no setterinherited
-
discussionLanguages
→ List<
LanguageView> -
no setterinherited
-
follows
→ List<
CommunityFollowerView> -
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
-
instanceBlocks
→ List<
InstanceBlockView> -
no setterinherited
- localUserView → LocalUserView
-
no setterinherited
-
moderates
→ List<
CommunityModeratorView> -
no setterinherited
-
personBlocks
→ List<
PersonBlockView> -
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serializes this MyUserInfo to a JSON map.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited