PersonAggregates class

Annotations
  • @freezed

Constructors

PersonAggregates({@JsonKey.new(name: 'person_id') required int personId, @JsonKey.new(name: 'post_count') @Default.new(0) int postCount, @JsonKey.new(name: 'comment_count') @Default.new(0) int commentCount})
const
factory
PersonAggregates.fromJson(Map<String, dynamic> json)
factory

Properties

commentCount int
no setterinherited
copyWith → $PersonAggregatesCopyWith<PersonAggregates>
Create a copy of PersonAggregates with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
personId int
no setterinherited
postCount int
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this PersonAggregates to a JSON map.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited