PersonBlockView class

Annotations
  • @freezed

Constructors

PersonBlockView({required Person person, required Person target})
const
factory
PersonBlockView.fromJson(Map<String, dynamic> json)
factory

Properties

copyWith → $PersonBlockViewCopyWith<PersonBlockView>
Create a copy of PersonBlockView with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
person Person
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
target Person
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this PersonBlockView to a JSON map.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited