PollChoice class
Constructors
-
PollChoice({required int id, @JsonKey.new(name: 'choice_text') required String choiceText, @JsonKey.new(name: 'sort_order') int? sortOrder, @JsonKey.new(name: 'num_votes') @Default.new(0) int numVotes})
-
const
factory
-
PollChoice.fromJson(Map<String, dynamic> json)
-
factory
Properties
-
choiceText
→ String
-
no setterinherited
-
copyWith
→ $PollChoiceCopyWith<PollChoice>
-
Create a copy of PollChoice
with the given fields replaced by the non-null parameter values.
no setterinherited
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
id
→ int
-
no setterinherited
-
numVotes
→ int
-
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
-
sortOrder
→ int?
-
no setterinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson()
→ Map<String, dynamic>
-
Serializes this PollChoice to a JSON map.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited