PostAggregates class

Annotations
  • @freezed

Constructors

PostAggregates({@JsonKey.new(name: 'post_id') required int postId, @Default.new(0) int comments, @Default.new(0) int score, @Default.new(0) int upvotes, @Default.new(0) int downvotes, @JsonKey.new(name: 'newest_comment_time') DateTime? newestCommentTime, @JsonKey.new(name: 'newest_comment_time_necro') DateTime? newestCommentTimeNecro})
const
factory
PostAggregates.fromJson(Map<String, dynamic> json)
factory

Properties

comments int
no setterinherited
copyWith → $PostAggregatesCopyWith<PostAggregates>
Create a copy of PostAggregates with the given fields replaced by the non-null parameter values.
no setterinherited
downvotes int
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
newestCommentTime DateTime?
no setterinherited
newestCommentTimeNecro DateTime?
no setterinherited
postId int
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
score int
no setterinherited
upvotes int
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this PostAggregates to a JSON map.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited