PrivateMessage class
- Annotations
-
- @freezed
Constructors
- PrivateMessage({required int id, @JsonKey.new(name: 'creator_id') required int creatorId, @JsonKey.new(name: 'recipient_id') required int recipientId, required String content, required bool deleted, required bool read, required DateTime published, DateTime? updated})
-
constfactory
-
PrivateMessage.fromJson(Map<
String, dynamic> json) -
factory
Properties
- content → String
-
no setterinherited
-
copyWith
→ $PrivateMessageCopyWith<
PrivateMessage> -
Create a copy of PrivateMessage
with the given fields replaced by the non-null parameter values.
no setterinherited
- creatorId → int
-
no setterinherited
- deleted → bool
-
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → int
-
no setterinherited
- published → DateTime
-
no setterinherited
- read → bool
-
no setterinherited
- recipientId → int
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- updated → DateTime?
-
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serializes this PrivateMessage to a JSON map.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited