PrivateMessageReport class

Annotations
  • @freezed

Constructors

PrivateMessageReport({required int id, @JsonKey.new(name: 'creator_id') required int creatorId, @JsonKey.new(name: 'private_message_id') required int privateMessageId, @JsonKey.new(name: 'original_pm_text') required String originalPmText, required String? reason, required bool resolved, required DateTime published})
const
factory
PrivateMessageReport.fromJson(Map<String, dynamic> json)
factory

Properties

copyWith → $PrivateMessageReportCopyWith<PrivateMessageReport>
Create a copy of PrivateMessageReport with the given fields replaced by the non-null parameter values.
no setterinherited
creatorId int
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
id int
no setterinherited
originalPmText String
no setterinherited
privateMessageId int
no setterinherited
published DateTime
no setterinherited
reason String?
no setterinherited
resolved bool
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this PrivateMessageReport to a JSON map.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited