PrivateMessagesResponse class

Annotations
  • @freezed

Constructors

PrivateMessagesResponse({@JsonKey.new(name: 'private_messages') required List<PrivateMessageView> privateMessages})
const
factory
PrivateMessagesResponse.fromJson(Map<String, dynamic> json)
factory

Properties

copyWith → $PrivateMessagesResponseCopyWith<PrivateMessagesResponse>
Create a copy of PrivateMessagesResponse with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
privateMessages List<PrivateMessageView>
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this PrivateMessagesResponse to a JSON map.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited