Reactions class

Annotations
  • @freezed

Constructors

Reactions({String? url, required String token, required List<String> authors, required int count, @JsonKey.new(name: 'my_reaction') String? myReaction})
const
factory
Reactions.fromJson(Map<String, dynamic> json)
factory

Properties

authors List<String>
no setterinherited
copyWith → $ReactionsCopyWith<Reactions>
Create a copy of Reactions with the given fields replaced by the non-null parameter values.
no setterinherited
count int
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
myReaction String?
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
token String
no setterinherited
url String?
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this Reactions to a JSON map.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited