ReportPost class

Implemented types
Annotations
  • @freezed

Constructors

ReportPost({@JsonKey.new(name: 'post_id') required int postId, required String reason, required String auth})
const
factory
ReportPost.fromJson(Map<String, dynamic> json)
factory

Properties

auth String
no setterinherited
copyWith → $ReportPostCopyWith<ReportPost>
Create a copy of ReportPost with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
httpMethod HttpMethod
The HTTP method for this request.
no setteroverride
isMultipart bool
Whether this query contains multipart files.
no setteroverride
multipartFiles List<MultipartFile>?
Optional list of multipart files for the request.
no setteroverride
path String
The API endpoint path (e.g., '/post', '/comment').
no setteroverride
postId int
no setterinherited
reason String
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
responseFactory(Map<String, dynamic> json) ReportPostResponse
Deserializes the JSON response into the expected type.
override
toJson() Map<String, dynamic>
Serializes this ReportPost to a JSON map.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited