SaveUserSettings class

Implemented types
Annotations
  • @freezed

Constructors

SaveUserSettings({@JsonKey.new(name: 'accept_private_messages') String? acceptPrivateMessages, String? avatar, String? bio, bool? bot, @JsonKey.new(name: 'display_name') String? displayName, @JsonKey.new(name: 'bot_visibility') String? botVisibility, @JsonKey.new(name: 'community_keyword_filter') List<String>? communityKeywordFilter, String? cover, @JsonKey.new(name: 'default_comment_sort_type') String? defaultCommentSortType, @JsonKey.new(name: 'default_sort_type') String? defaultSortType, @JsonKey.new(name: 'email_unread') bool? emailUnread, @JsonKey.new(name: 'extra_fields') List<String>? extraFields, @JsonKey.new(name: 'federate_votes') bool? federateVotes, @JsonKey.new(name: 'feed_auto_follow') bool? feedAutoFollow, @JsonKey.new(name: 'feed_auto_leave') bool? feedAutoLeave, @JsonKey.new(name: 'hide_low_quality') bool? hideLowQuality, bool? indexable, bool? newsletter, @JsonKey.new(name: 'nsfl_visibility') String? nsflVisibility, @JsonKey.new(name: 'nsfw_visibility') String? nsfwVisibility, @JsonKey.new(name: 'genai_visibility') String? genaiVisibility, @JsonKey.new(name: 'reply_collapse_threshold') int? replyCollapseThreshold, @JsonKey.new(name: 'reply_hide_threshold') int? replyHideThreshold, @JsonKey.new(name: 'show_nsfw') bool? showNsfw, @JsonKey.new(name: 'show_nsfl') bool? showNsfl, @JsonKey.new(name: 'show_read_posts') bool? showReadPosts, bool? searchable, required String auth})
const
factory
SaveUserSettings.fromJson(Map<String, dynamic> json)
factory

Properties

acceptPrivateMessages String?
no setterinherited
auth String
no setterinherited
avatar String?
no setterinherited
bio String?
no setterinherited
bot bool?
no setterinherited
botVisibility String?
no setterinherited
communityKeywordFilter List<String>?
no setterinherited
copyWith → $SaveUserSettingsCopyWith<SaveUserSettings>
Create a copy of SaveUserSettings with the given fields replaced by the non-null parameter values.
no setterinherited
cover String?
no setterinherited
defaultCommentSortType String?
no setterinherited
defaultSortType String?
no setterinherited
displayName String?
no setterinherited
emailUnread bool?
no setterinherited
extraFields List<String>?
no setterinherited
federateVotes bool?
no setterinherited
feedAutoFollow bool?
no setterinherited
feedAutoLeave bool?
no setterinherited
genaiVisibility String?
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
hideLowQuality bool?
no setterinherited
httpMethod HttpMethod
The HTTP method for this request.
no setteroverride
indexable bool?
no setterinherited
isMultipart bool
Whether this query contains multipart files.
no setteroverride
multipartFiles List<MultipartFile>?
Optional list of multipart files for the request.
no setteroverride
newsletter bool?
no setterinherited
nsflVisibility String?
no setterinherited
nsfwVisibility String?
no setterinherited
path String
The API endpoint path (e.g., '/post', '/comment').
no setteroverride
replyCollapseThreshold int?
no setterinherited
replyHideThreshold int?
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
searchable bool?
no setterinherited
showNsfl bool?
no setterinherited
showNsfw bool?
no setterinherited
showReadPosts bool?
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
responseFactory(Map<String, dynamic> json) UserSaveSettingsResponse
Deserializes the JSON response into the expected type.
override
toJson() Map<String, dynamic>
Serializes this SaveUserSettings to a JSON map.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited