SearchResponse class

Annotations
  • @freezed

Constructors

SearchResponse({@JsonKey.new(name: 'type_') required String type, required List<CommentView> comments, required List<PostView> posts, required List<CommunityView> communities, required List<PersonView> users})
const
factory
SearchResponse.fromJson(Map<String, dynamic> json)
factory

Properties

comments List<CommentView>
no setterinherited
communities List<CommunityView>
no setterinherited
copyWith → $SearchResponseCopyWith<SearchResponse>
Create a copy of SearchResponse with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
posts List<PostView>
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String
no setterinherited
users List<PersonView>
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this SearchResponse to a JSON map.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited