SubscribeComment class

Implemented types
Annotations
  • @freezed

Constructors

SubscribeComment({@JsonKey.new(name: 'comment_id') required int commentId, required bool subscribe, required String auth})
const
factory
SubscribeComment.fromJson(Map<String, dynamic> json)
factory

Properties

auth String
no setterinherited
commentId int
no setterinherited
copyWith → $SubscribeCommentCopyWith<SubscribeComment>
Create a copy of SubscribeComment with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
httpMethod HttpMethod
The HTTP method for this request.
no setteroverride
isMultipart bool
Whether this query contains multipart files.
no setteroverride
multipartFiles List<MultipartFile>?
Optional list of multipart files for the request.
no setteroverride
path String
The API endpoint path (e.g., '/post', '/comment').
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subscribe bool
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
responseFactory(Map<String, dynamic> json) GetCommentResponse
Deserializes the JSON response into the expected type.
override
toJson() Map<String, dynamic>
Serializes this SubscribeComment to a JSON map.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited