SubscribePost class

Implemented types
Annotations
  • @freezed

Constructors

SubscribePost({@JsonKey.new(name: 'post_id') required int postId, required bool subscribe, required String auth})
const
factory
SubscribePost.fromJson(Map<String, dynamic> json)
factory

Properties

auth String
no setterinherited
copyWith → $SubscribePostCopyWith<SubscribePost>
Create a copy of SubscribePost with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
httpMethod HttpMethod
The HTTP method for this request.
no setteroverride
isMultipart bool
Whether this query contains multipart files.
no setteroverride
multipartFiles List<MultipartFile>?
Optional list of multipart files for the request.
no setteroverride
path String
The API endpoint path (e.g., '/post', '/comment').
no setteroverride
postId int
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subscribe bool
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
responseFactory(Map<String, dynamic> json) GetPostResponse
Deserializes the JSON response into the expected type.
override
toJson() Map<String, dynamic>
Serializes this SubscribePost to a JSON map.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited