TopicView class

Annotations
  • @freezed

Constructors

TopicView({required int id, required String name, required String title, @JsonKey.new(name: 'communities_count') required int communitiesCount, @JsonKey.new(name: 'show_posts_from_children') required bool showPostsFromChildren, @JsonKey.new(name: 'parent_topic_id') int? parentTopicId, required List<Community> communities, required List<TopicView> children})
const
factory
TopicView.fromJson(Map<String, dynamic> json)
factory

Properties

children List<TopicView>
no setterinherited
communities List<Community>
no setterinherited
communitiesCount int
no setterinherited
copyWith → $TopicViewCopyWith<TopicView>
Create a copy of TopicView with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
id int
no setterinherited
name String
no setterinherited
parentTopicId int?
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showPostsFromChildren bool
no setterinherited
title String
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this TopicView to a JSON map.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited