UploadCommunityImage class

Implemented types
Annotations
  • @freezed

Constructors

UploadCommunityImage({@JsonKey.new(includeFromJson: false, includeToJson: false) required MultipartFile file, @JsonKey.new(name: 'community_id') required int communityId, required String auth})
factory

Properties

auth String
no setterinherited
communityId int
no setterinherited
copyWith → $UploadCommunityImageCopyWith<UploadCommunityImage>
Create a copy of UploadCommunityImage with the given fields replaced by the non-null parameter values.
no setterinherited
file → MultipartFile
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
httpMethod HttpMethod
The HTTP method for this request.
no setteroverride
isMultipart bool
Whether this query contains multipart files.
no setteroverride
multipartFiles List<MultipartFile>
Optional list of multipart files for the request.
no setteroverride
path String
The API endpoint path (e.g., '/post', '/comment').
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
responseFactory(Map<String, dynamic> json) UploadImageResponse
Deserializes the JSON response into the expected type.
override
toJson() Map<String, dynamic>
Serializes the request parameters to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited