UploadImageResponse class

Annotations
  • @freezed

Constructors

UploadImageResponse({@JsonKey.new(name: 'msg') String? msg, String? url, @JsonKey.new(name: 'delete_url') String? deleteUrl})
const
factory
UploadImageResponse.fromJson(Map<String, dynamic> json)
factory

Properties

copyWith → $UploadImageResponseCopyWith<UploadImageResponse>
Create a copy of UploadImageResponse with the given fields replaced by the non-null parameter values.
no setterinherited
deleteUrl String?
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
msg String?
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
url String?
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this UploadImageResponse to a JSON map.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited