UserMarkAllNotifsReadResponse class

Annotations
  • @freezed

Constructors

UserMarkAllNotifsReadResponse({@JsonKey.new(name: 'mark_all_notifications_as_read') required String markAllNotificationsAsRead})
const
factory
UserMarkAllNotifsReadResponse.fromJson(Map<String, dynamic> json)
factory

Properties

copyWith → $UserMarkAllNotifsReadResponseCopyWith<UserMarkAllNotifsReadResponse>
Create a copy of UserMarkAllNotifsReadResponse with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
markAllNotificationsAsRead String
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this UserMarkAllNotifsReadResponse to a JSON map.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited