UserMediaResponse class
Properties
-
copyWith
→ $UserMediaResponseCopyWith<UserMediaResponse>
-
Create a copy of UserMediaResponse
with the given fields replaced by the non-null parameter values.
no setterinherited
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
media
→ List<MediaView>
-
no setterinherited
-
nextPage
→ String?
-
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson()
→ Map<String, dynamic>
-
Serializes this UserMediaResponse to a JSON map.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited