UserNotificationsResponse class

Annotations
  • @freezed

Constructors

UserNotificationsResponse({required UserNotificationsCounts counts, required List<UserNotificationItemView> items, required String status, required String username, @JsonKey.new(name: 'next_page') String? nextPage})
const
factory
UserNotificationsResponse.fromJson(Map<String, dynamic> json)
factory

Properties

copyWith → $UserNotificationsResponseCopyWith<UserNotificationsResponse>
Create a copy of UserNotificationsResponse with the given fields replaced by the non-null parameter values.
no setterinherited
counts UserNotificationsCounts
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
items List<UserNotificationItemView>
no setterinherited
nextPage String?
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status String
no setterinherited
username String
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this UserNotificationsResponse to a JSON map.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited