UserRegistration class
- Annotations
-
- @freezed
Constructors
- UserRegistration({required String? answer, @JsonKey.new(name: 'applied_at') DateTime? appliedAt, @JsonKey.new(name: 'country_code') String? countryCode, required String? email, @JsonKey.new(name: 'ip_address') required String? ipAddress, @JsonKey.new(name: 'throwaway_email') bool? throwawayEmail, @JsonKey.new(name: 'user_id') required int userId, @JsonKey.new(name: 'user_name') required String userName, required String status, @JsonKey.new(name: 'approved_by') Person? approvedBy, @JsonKey.new(name: 'approved_at') DateTime? approvedAt, String? referrer})
-
constfactory
-
UserRegistration.fromJson(Map<
String, dynamic> json) -
factory
Properties
- answer → String?
-
no setterinherited
- appliedAt → DateTime?
-
no setterinherited
- approvedAt → DateTime?
-
no setterinherited
- approvedBy → Person?
-
no setterinherited
-
copyWith
→ $UserRegistrationCopyWith<
UserRegistration> -
Create a copy of UserRegistration
with the given fields replaced by the non-null parameter values.
no setterinherited
- countryCode → String?
-
no setterinherited
- email → String?
-
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- ipAddress → String?
-
no setterinherited
- referrer → String?
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status → String
-
no setterinherited
- throwawayEmail → bool?
-
no setterinherited
- userId → int
-
no setterinherited
- userName → String
-
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serializes this UserRegistration to a JSON map.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited