Comment class
- Annotations
-
- @freezed
Constructors
-
Comment({required int id, @JsonKey.new(name: 'ap_id') required String apId, @JsonKey.new(name: 'user_id') int? userId, @JsonKey.new(name: 'post_id') required int postId, required String body, required bool local, required bool deleted, required bool removed, required String path, required bool distinguished, @JsonKey.new(name: 'language_id') int? languageId, required DateTime published, DateTime? updated, bool? locked, @Default.new(false) bool answer, @JsonKey.new(name: 'emoji_reactions') List<
Reactions> ? emojiReactions}) -
constfactory
-
Comment.fromJson(Map<
String, dynamic> json) -
factory
Properties
- answer → bool
-
no setterinherited
- apId → String
-
no setterinherited
- body → String
-
no setterinherited
-
copyWith
→ $CommentCopyWith<
Comment> -
Create a copy of Comment
with the given fields replaced by the non-null parameter values.
no setterinherited
- deleted → bool
-
no setterinherited
- distinguished → bool
-
no setterinherited
-
emojiReactions
→ List<
Reactions> ? -
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → int
-
no setterinherited
- languageId → int?
-
no setterinherited
- local → bool
-
no setterinherited
- locked → bool?
-
no setterinherited
- path → String
-
no setterinherited
- postId → int
-
no setterinherited
- published → DateTime
-
no setterinherited
- removed → bool
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- updated → DateTime?
-
no setterinherited
- userId → int?
-
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serializes this Comment to a JSON map.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited