CommentReport class
- Annotations
-
- @freezed
Constructors
- CommentReport({required int id, @JsonKey.new(name: 'creator_id') required int creatorId, @JsonKey.new(name: 'comment_id') required int commentId, @JsonKey.new(name: 'original_comment_text') String? originalCommentText, String? reason, String? description, required bool resolved, required DateTime published, DateTime? updated})
-
constfactory
-
CommentReport.fromJson(Map<
String, dynamic> json) -
factory
Properties
- commentId → int
-
no setterinherited
-
copyWith
→ $CommentReportCopyWith<
CommentReport> -
Create a copy of CommentReport
with the given fields replaced by the non-null parameter values.
no setterinherited
- creatorId → int
-
no setterinherited
- description → String?
-
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → int
-
no setterinherited
- originalCommentText → String?
-
no setterinherited
- published → DateTime
-
no setterinherited
- reason → String?
-
no setterinherited
- resolved → bool
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- updated → DateTime?
-
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serializes this CommentReport to a JSON map.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited