CommunityFlairDeleteResponse class
- Annotations
-
- @freezed
Constructors
-
CommunityFlairDeleteResponse({@JsonKey.new(name: 'community_view') CommunityView? communityView, @JsonKey.new(name: 'discussion_languages') List<
int> ? discussionLanguages, List<CommunityModeratorView> ? moderators, Site? site}) -
constfactory
-
CommunityFlairDeleteResponse.fromJson(Map<
String, dynamic> json) -
factory
Properties
- communityView → CommunityView?
-
no setterinherited
-
copyWith
→ $CommunityFlairDeleteResponseCopyWith<
CommunityFlairDeleteResponse> -
Create a copy of CommunityFlairDeleteResponse
with the given fields replaced by the non-null parameter values.
no setterinherited
-
discussionLanguages
→ List<
int> ? -
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
-
moderators
→ List<
CommunityModeratorView> ? -
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- site → Site?
-
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serializes this CommunityFlairDeleteResponse to a JSON map.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited