CommunityView class
- Annotations
-
- @freezed
Constructors
-
CommunityView({required Community community, @JsonKey.new(fromJson: _subscribedFromJson) required SubscribedType subscribed, required bool blocked, required CommunityAggregates counts, @JsonKey.new(name: 'activity_alert') bool? activityAlert, @JsonKey.new(name: 'flair_list') List<
CommunityFlair> ? flairList}) -
constfactory
-
CommunityView.fromJson(Map<
String, dynamic> json) -
factory
Properties
- activityAlert → bool?
-
no setterinherited
- blocked → bool
-
no setterinherited
- community → Community
-
no setterinherited
-
copyWith
→ $CommunityViewCopyWith<
CommunityView> -
Create a copy of CommunityView
with the given fields replaced by the non-null parameter values.
no setterinherited
- counts → CommunityAggregates
-
no setterinherited
-
flairList
→ List<
CommunityFlair> ? -
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- subscribed → SubscribedType
-
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serializes this CommunityView to a JSON map.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited