ConversationReportView class
- Annotations
-
- @freezed
Constructors
-
ConversationReportView({@JsonKey.new(name: 'conversation_report') required ConversationReport conversationReport, @JsonKey.new(name: 'conversation_information') required ConversationInfoView conversationInformation, @JsonKey.new(name: 'message_history') List<
PrivateMessageView> ? messageHistory, required Person creator}) -
constfactory
-
ConversationReportView.fromJson(Map<
String, dynamic> json) -
factory
Properties
- conversationInformation → ConversationInfoView
-
no setterinherited
- conversationReport → ConversationReport
-
no setterinherited
-
copyWith
→ $ConversationReportViewCopyWith<
ConversationReportView> -
Create a copy of ConversationReportView
with the given fields replaced by the non-null parameter values.
no setterinherited
- creator → Person
-
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
-
messageHistory
→ List<
PrivateMessageView> ? -
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serializes this ConversationReportView to a JSON map.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited