CreateCommunity class
- Implemented types
- Annotations
-
- @freezed
Constructors
-
CreateCommunity({required String name, required String title, String? description, String? icon, String? banner, @JsonKey.new(name: 'nsfw') bool? nsfw, @JsonKey.new(name: 'posting_restricted_to_mods') bool? postingRestrictedToMods, @JsonKey.new(name: 'discussion_languages') List<
int> ? discussionLanguages, required String auth}) -
constfactory
-
CreateCommunity.fromJson(Map<
String, dynamic> json) -
factory
Properties
- auth → String
-
no setterinherited
-
no setterinherited
-
copyWith
→ $CreateCommunityCopyWith<
CreateCommunity> -
Create a copy of CreateCommunity
with the given fields replaced by the non-null parameter values.
no setterinherited
- description → String?
-
no setterinherited
-
discussionLanguages
→ List<
int> ? -
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- httpMethod → HttpMethod
-
The HTTP method for this request.
no setteroverride
- icon → String?
-
no setterinherited
- isMultipart → bool
-
Whether this query contains multipart files.
no setteroverride
-
multipartFiles
→ List<
MultipartFile> ? -
Optional list of multipart files for the request.
no setteroverride
- name → String
-
no setterinherited
- nsfw → bool?
-
no setterinherited
- path → String
-
The API endpoint path (e.g., '/post', '/comment').
no setteroverride
- postingRestrictedToMods → bool?
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- title → String
-
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
responseFactory(
Map< String, dynamic> json) → GetCommunityResponse -
Deserializes the JSON response into the expected type.
override
-
toJson(
) → Map< String, dynamic> -
Serializes this CreateCommunity to a JSON map.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited