GetModLogResponse class
- Annotations
-
- @freezed
Constructors
-
GetModLogResponse({@JsonKey.new(name: 'removed_posts') @Default.new(<ModRemovePostView>[]) List<
ModRemovePostView> removedPosts, @JsonKey.new(name: 'locked_posts') @Default.new(<ModLockPostView>[]) List<ModLockPostView> lockedPosts, @JsonKey.new(name: 'featured_posts') @Default.new(<ModFeaturePostView>[]) List<ModFeaturePostView> featuredPosts, @JsonKey.new(name: 'removed_comments') @Default.new(<ModRemoveCommentView>[]) List<ModRemoveCommentView> removedComments, @JsonKey.new(name: 'removed_communities') @Default.new(<ModRemoveCommunityView>[]) List<ModRemoveCommunityView> removedCommunities, @JsonKey.new(name: 'banned_from_community') @Default.new(<ModBanFromCommunityView>[]) List<ModBanFromCommunityView> bannedFromCommunity, @Default.new(<ModBanView>[]) List<ModBanView> banned, @JsonKey.new(name: 'added_to_community') @Default.new(<ModAddCommunityView>[]) List<ModAddCommunityView> addedToCommunity, @JsonKey.new(name: 'transferred_to_community') @Default.new(<ModTransferCommunityView>[]) List<ModTransferCommunityView> transferredToCommunity, @Default.new(<ModAddView>[]) List<ModAddView> added, @JsonKey.new(name: 'admin_purged_persons') @Default.new(<AdminPurgePersonView>[]) List<AdminPurgePersonView> adminPurgedPersons, @JsonKey.new(name: 'admin_purged_communities') @Default.new(<AdminPurgeCommunityView>[]) List<AdminPurgeCommunityView> adminPurgedCommunities, @JsonKey.new(name: 'admin_purged_posts') @Default.new(<AdminPurgePostView>[]) List<AdminPurgePostView> adminPurgedPosts, @JsonKey.new(name: 'admin_purged_comments') @Default.new(<AdminPurgeCommentView>[]) List<AdminPurgeCommentView> adminPurgedComments, }) -
constfactory
-
GetModLogResponse.fromJson(Map<
String, dynamic> json) -
factory
Properties
-
added
→ List<
ModAddView> -
no setterinherited
-
addedToCommunity
→ List<
ModAddCommunityView> -
no setterinherited
-
adminPurgedComments
→ List<
AdminPurgeCommentView> -
no setterinherited
-
adminPurgedCommunities
→ List<
AdminPurgeCommunityView> -
no setterinherited
-
adminPurgedPersons
→ List<
AdminPurgePersonView> -
no setterinherited
-
adminPurgedPosts
→ List<
AdminPurgePostView> -
no setterinherited
-
banned
→ List<
ModBanView> -
no setterinherited
-
bannedFromCommunity
→ List<
ModBanFromCommunityView> -
no setterinherited
-
copyWith
→ $GetModLogResponseCopyWith<
GetModLogResponse> -
Create a copy of GetModLogResponse
with the given fields replaced by the non-null parameter values.
no setterinherited
-
featuredPosts
→ List<
ModFeaturePostView> -
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
-
no setterinherited
-
lockedPosts
→ List<
ModLockPostView> -
no setterinherited
-
removedComments
→ List<
ModRemoveCommentView> -
no setterinherited
-
removedCommunities
→ List<
ModRemoveCommunityView> -
no setterinherited
-
removedPosts
→ List<
ModRemovePostView> -
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
transferredToCommunity
→ List<
ModTransferCommunityView> -
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serializes this GetModLogResponse to a JSON map.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited