LikeComment class
Query to upvote/downvote a comment.
- Implemented types
- Annotations
-
- @freezed
Constructors
- LikeComment({@JsonKey.new(name: 'comment_id') required int commentId, required int score, required String auth, String? emoji, bool? private})
-
constfactory
-
LikeComment.fromJson(Map<
String, dynamic> json) -
factory
Properties
- auth → String
-
Auth token.
no setterinherited
- commentId → int
-
The comment to vote on.
no setterinherited
-
copyWith
→ $LikeCommentCopyWith<
LikeComment> -
Create a copy of LikeComment
with the given fields replaced by the non-null parameter values.
no setterinherited
- emoji → String?
-
Optional emoji for the vote.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- httpMethod → HttpMethod
-
The HTTP method for this request.
no setteroverride
- isMultipart → bool
-
Whether this query contains multipart files.
no setteroverride
-
multipartFiles
→ List<
MultipartFile> ? -
Optional list of multipart files for the request.
no setteroverride
- path → String
-
The API endpoint path (e.g., '/post', '/comment').
no setteroverride
- private → bool?
-
Whether the vote is private.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- score → int
-
The vote score: 1 = upvote, -1 = downvote, 0 = remove vote.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
responseFactory(
Map< String, dynamic> json) → GetCommentResponse -
Deserializes the JSON response into the expected type.
override
-
toJson(
) → Map< String, dynamic> -
Serializes this LikeComment to a JSON map.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited