ModFeaturePostView class
- Annotations
-
- @freezed
Constructors
- ModFeaturePostView({@JsonKey.new(name: 'mod_feature_post') required ModFeaturePost modFeaturePost, Person? moderator, Post? post, Community? community})
-
constfactory
-
ModFeaturePostView.fromJson(Map<
String, dynamic> json) -
factory
Properties
- community → Community?
-
no setterinherited
-
copyWith
→ $ModFeaturePostViewCopyWith<
ModFeaturePostView> -
Create a copy of ModFeaturePostView
with the given fields replaced by the non-null parameter values.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- moderator → Person?
-
no setterinherited
- modFeaturePost → ModFeaturePost
-
no setterinherited
- post → Post?
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serializes this ModFeaturePostView to a JSON map.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited