ModRemoveCommentView class

Annotations
  • @freezed

Constructors

ModRemoveCommentView({@JsonKey.new(name: 'mod_remove_comment') required ModRemoveComment modRemoveComment, Person? moderator, Comment? comment, Person? commenter, Post? post, Community? community})
const
factory
ModRemoveCommentView.fromJson(Map<String, dynamic> json)
factory

Properties

comment Comment?
no setterinherited
commenter Person?
no setterinherited
community Community?
no setterinherited
copyWith → $ModRemoveCommentViewCopyWith<ModRemoveCommentView>
Create a copy of ModRemoveCommentView with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
moderator Person?
no setterinherited
modRemoveComment ModRemoveComment
no setterinherited
post Post?
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this ModRemoveCommentView to a JSON map.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited