Person class
- Annotations
-
- @freezed
Constructors
-
Person({required int id, @JsonKey.new(name: 'user_name') required String name, @JsonKey.new(name: 'actor_id') required String actorId, required bool local, required bool banned, required bool bot, required bool deleted, @JsonKey.new(name: 'instance_id') required int instanceId, @JsonKey.new(name: 'display_name') String? displayName, String? avatar, String? banner, String? bio, String? about, @JsonKey.new(name: 'about_html') String? aboutHtml, @JsonKey.new(name: 'extra_fields') List<
UserExtraField> ? extraFields, String? note, String? flair, String? title, DateTime? published}) -
constfactory
-
Person.fromJson(Map<
String, dynamic> json) -
factory
Properties
- about → String?
-
no setterinherited
- aboutHtml → String?
-
no setterinherited
- actorId → String
-
no setterinherited
- avatar → String?
-
no setterinherited
- banned → bool
-
no setterinherited
-
no setterinherited
- bio → String?
-
no setterinherited
- bot → bool
-
no setterinherited
-
copyWith
→ $PersonCopyWith<
Person> -
Create a copy of Person
with the given fields replaced by the non-null parameter values.
no setterinherited
- deleted → bool
-
no setterinherited
- displayName → String?
-
no setterinherited
-
extraFields
→ List<
UserExtraField> ? -
no setterinherited
- flair → String?
-
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → int
-
no setterinherited
- instanceId → int
-
no setterinherited
- local → bool
-
no setterinherited
- name → String
-
no setterinherited
- note → String?
-
no setterinherited
- published → DateTime?
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- title → String?
-
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serializes this Person to a JSON map.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited