PersonView class

Annotations
  • @freezed

Constructors

PersonView({required Person person, PersonAggregates? counts, @JsonKey.new(name: 'is_admin') required bool isAdmin, @JsonKey.new(name: 'activity_alert') bool? activityAlert})
const
factory
PersonView.fromJson(Map<String, dynamic> json)
factory

Properties

activityAlert bool?
no setterinherited
copyWith → $PersonViewCopyWith<PersonView>
Create a copy of PersonView with the given fields replaced by the non-null parameter values.
no setterinherited
counts PersonAggregates?
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
isAdmin bool
no setterinherited
person Person
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this PersonView to a JSON map.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited