PostEvent class
- Annotations
-
- @freezed
Constructors
- PostEvent({required DateTime start, required DateTime end, String? timezone, @JsonKey.new(name: 'max_attendees', defaultValue: 0) required int maxAttendees, @JsonKey.new(name: 'participant_count', defaultValue: 0) required int participantCount, @Default.new(false) bool full, @JsonKey.new(name: 'online_link') String? onlineLink, @JsonKey.new(name: 'join_mode') String? joinMode, @JsonKey.new(name: 'external_participation_url') String? externalParticipationUrl, @JsonKey.new(name: 'anonymous_participation', defaultValue: false) required bool anonymousParticipation, @Default.new(false) bool online, @JsonKey.new(name: 'buy_tickets_link') String? buyTicketsLink, @JsonKey.new(name: 'event_fee_currency') String? eventFeeCurrency, @JsonKey.new(name: 'event_fee_amount') num? eventFeeAmount, @JsonKey.new(name: 'my_participation') String? myParticipation})
-
constfactory
-
PostEvent.fromJson(Map<
String, dynamic> json) -
factory
Properties
- anonymousParticipation → bool
-
no setterinherited
- buyTicketsLink → String?
-
no setterinherited
-
copyWith
→ $PostEventCopyWith<
PostEvent> -
Create a copy of PostEvent
with the given fields replaced by the non-null parameter values.
no setterinherited
- end → DateTime
-
no setterinherited
- eventFeeAmount → num?
-
no setterinherited
- eventFeeCurrency → String?
-
no setterinherited
- externalParticipationUrl → String?
-
no setterinherited
- full → bool
-
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- joinMode → String?
-
no setterinherited
- maxAttendees → int
-
no setterinherited
- myParticipation → String?
-
no setterinherited
- online → bool
-
no setterinherited
- onlineLink → String?
-
no setterinherited
- participantCount → int
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- start → DateTime
-
no setterinherited
- timezone → String?
-
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serializes this PostEvent to a JSON map.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited