PostPoll class

Annotations
  • @freezed

Constructors

PostPoll({@JsonKey.new(name: 'end_poll') DateTime? endPoll, String? mode, @JsonKey.new(name: 'local_only') bool? localOnly, @JsonKey.new(name: 'latest_vote') DateTime? latestVote, @Default.new([]) List<PollChoice> choices, @JsonKey.new(name: 'my_votes') List<int>? myVotes})
const
factory
PostPoll.fromJson(Map<String, dynamic> json)
factory

Properties

choices List<PollChoice>
no setterinherited
copyWith → $PostPollCopyWith<PostPoll>
Create a copy of PostPoll with the given fields replaced by the non-null parameter values.
no setterinherited
endPoll DateTime?
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
latestVote DateTime?
no setterinherited
localOnly bool?
no setterinherited
mode String?
no setterinherited
myVotes List<int>?
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this PostPoll to a JSON map.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited