PostReport class

Annotations
  • @freezed

Constructors

PostReport({required int id, @JsonKey.new(name: 'creator_id') required int creatorId, @JsonKey.new(name: 'post_id') required int postId, @JsonKey.new(name: 'original_post_name') String? originalPostName, @JsonKey.new(name: 'original_post_body') required String originalPostBody, required String reason, required bool resolved, required DateTime published})
const
factory
PostReport.fromJson(Map<String, dynamic> json)
factory

Properties

copyWith → $PostReportCopyWith<PostReport>
Create a copy of PostReport with the given fields replaced by the non-null parameter values.
no setterinherited
creatorId int
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
id int
no setterinherited
originalPostBody String
no setterinherited
originalPostName String?
no setterinherited
postId int
no setterinherited
published DateTime
no setterinherited
reason String
no setterinherited
resolved bool
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this PostReport to a JSON map.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited