PostReportView class
- Annotations
-
- @freezed
Constructors
- PostReportView({@JsonKey.new(name: 'post_report') required PostReport postReport, required Post post, required Community community, required Person creator, @JsonKey.new(name: 'post_creator') required Person postCreator, required PostAggregates counts, @JsonKey.new(name: 'creator_banned_from_community') required bool creatorBannedFromCommunity, @JsonKey.new(name: 'creator_is_moderator') required bool creatorIsModerator, @JsonKey.new(name: 'creator_is_admin') required bool creatorIsAdmin, @JsonKey.new(name: 'creator_blocked') required bool creatorBlocked, @JsonKey.new(fromJson: _subscribedFromJson) required SubscribedType subscribed, required bool saved})
-
constfactory
-
PostReportView.fromJson(Map<
String, dynamic> json) -
factory
Properties
- community → Community
-
no setterinherited
-
copyWith
→ $PostReportViewCopyWith<
PostReportView> -
Create a copy of PostReportView
with the given fields replaced by the non-null parameter values.
no setterinherited
- counts → PostAggregates
-
no setterinherited
- creator → Person
-
no setterinherited
- creatorBannedFromCommunity → bool
-
no setterinherited
- creatorBlocked → bool
-
no setterinherited
- creatorIsAdmin → bool
-
no setterinherited
- creatorIsModerator → bool
-
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- post → Post
-
no setterinherited
- postCreator → Person
-
no setterinherited
- postReport → PostReport
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- saved → bool
-
no setterinherited
- subscribed → SubscribedType
-
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serializes this PostReportView to a JSON map.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited