PostView class

Annotations
  • @freezed

Constructors

PostView({required Post post, required Person creator, required Community community, @JsonKey.new(name: 'creator_banned_from_community', defaultValue: false) required bool creatorBannedFromCommunity, required PostAggregates counts, @JsonKey.new(fromJson: _subscribedFromJson) required SubscribedType subscribed, required bool saved, required bool read, @JsonKey.new(name: 'creator_blocked', defaultValue: false) required bool creatorBlocked, @JsonKey.new(name: 'my_vote') int? myVote, @JsonKey.new(name: 'flair_list') List<CommunityFlair>? flairList, @JsonKey.new(name: 'can_auth_user_moderate') bool? canAuthUserModerate, @JsonKey.new(name: 'activity_alert') bool? activityAlert, @JsonKey.new(name: 'banned_from_community') bool? bannedFromCommunity, @JsonKey.new(name: 'creator_is_admin') bool? creatorIsAdmin, @JsonKey.new(name: 'creator_is_moderator') bool? creatorIsModerator, bool? hidden, @JsonKey.new(name: 'unread_comments') int? unreadComments, @JsonKey.new(name: 'alt_text') String? altText})
const
factory
PostView.fromJson(Map<String, dynamic> json)
factory

Properties

activityAlert bool?
no setterinherited
altText String?
no setterinherited
bannedFromCommunity bool?
no setterinherited
canAuthUserModerate bool?
no setterinherited
community Community
no setterinherited
copyWith → $PostViewCopyWith<PostView>
Create a copy of PostView with the given fields replaced by the non-null parameter values.
no setterinherited
counts PostAggregates
no setterinherited
creator Person
no setterinherited
creatorBannedFromCommunity bool
no setterinherited
creatorBlocked bool
no setterinherited
creatorIsAdmin bool?
no setterinherited
creatorIsModerator bool?
no setterinherited
flairList List<CommunityFlair>?
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
hidden bool?
no setterinherited
myVote int?
no setterinherited
post Post
no setterinherited
read bool
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
saved bool
no setterinherited
subscribed SubscribedType
no setterinherited
unreadComments int?
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this PostView to a JSON map.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited