PrivateMessageReportView class

Annotations
  • @freezed

Constructors

PrivateMessageReportView({@JsonKey.new(name: 'private_message_report') PrivateMessageReport? privateMessageReport, @JsonKey.new(name: 'private_message') PrivateMessage? privateMessage, @JsonKey.new(name: 'private_message_creator') Person? privateMessageCreator, Person? creator})
const
factory
PrivateMessageReportView.fromJson(Map<String, dynamic> json)
factory

Properties

copyWith → $PrivateMessageReportViewCopyWith<PrivateMessageReportView>
Create a copy of PrivateMessageReportView with the given fields replaced by the non-null parameter values.
no setterinherited
creator Person?
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
privateMessage PrivateMessage?
no setterinherited
privateMessageCreator Person?
no setterinherited
privateMessageReport PrivateMessageReport?
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this PrivateMessageReportView to a JSON map.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited