Register class
- Implemented types
- Annotations
-
- @freezed
Constructors
- Register({required String username, required String password, @JsonKey.new(name: 'password_verify') required String passwordVerify, @JsonKey.new(name: 'show_nsfw') bool? showNsfw, String? email, @JsonKey.new(name: 'captcha_uuid') String? captchaUuid, @JsonKey.new(name: 'captcha_answer') String? captchaAnswer, String? honeypot, String? answer})
-
constfactory
-
Register.fromJson(Map<
String, dynamic> json) -
factory
Properties
- answer → String?
-
no setterinherited
- captchaAnswer → String?
-
no setterinherited
- captchaUuid → String?
-
no setterinherited
-
copyWith
→ $RegisterCopyWith<
Register> -
Create a copy of Register
with the given fields replaced by the non-null parameter values.
no setterinherited
- email → String?
-
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- honeypot → String?
-
no setterinherited
- httpMethod → HttpMethod
-
The HTTP method for this request.
no setteroverride
- isMultipart → bool
-
Whether this query contains multipart files.
no setteroverride
-
multipartFiles
→ List<
MultipartFile> ? -
Optional list of multipart files for the request.
no setteroverride
- password → String
-
no setterinherited
- passwordVerify → String
-
no setterinherited
- path → String
-
The API endpoint path (e.g., '/post', '/comment').
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showNsfw → bool?
-
no setterinherited
- username → String
-
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
responseFactory(
Map< String, dynamic> json) → UserRegistrationResponse -
Deserializes the JSON response into the expected type.
override
-
toJson(
) → Map< String, dynamic> -
Serializes this Register to a JSON map.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited