Site class
- Annotations
-
- @freezed
Constructors
-
Site({@JsonKey.new(name: 'actor_id') required String actorId, required String name, String? description, String? icon, @JsonKey.new(name: 'enable_downvotes') required bool enableDownvotes, @JsonKey.new(name: 'registration_mode') required String registrationMode, String? sidebar, @JsonKey.new(name: 'sidebar_md') String? sidebarMd, @JsonKey.new(name: 'user_count') int? userCount, @JsonKey.new(name: 'all_languages') List<
LanguageView> ? allLanguages}) -
constfactory
-
Site.fromJson(Map<
String, dynamic> json) -
factory
Properties
- actorId → String
-
no setterinherited
-
allLanguages
→ List<
LanguageView> ? -
no setterinherited
-
copyWith
→ $SiteCopyWith<
Site> -
Create a copy of Site
with the given fields replaced by the non-null parameter values.
no setterinherited
- description → String?
-
no setterinherited
- enableDownvotes → bool
-
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- icon → String?
-
no setterinherited
- name → String
-
no setterinherited
- registrationMode → String
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
no setterinherited
-
no setterinherited
- userCount → int?
-
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serializes this Site to a JSON map.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited