UserNotificationItemView class
- Annotations
-
- @freezed
Constructors
- UserNotificationItemView({required Person author, @JsonKey.new(name: 'notif_body') required String notifBody, @JsonKey.new(name: 'notif_id') required int notifId, @JsonKey.new(name: 'notif_subtype') required String notifSubtype, @JsonKey.new(name: 'notif_type') required int notifType, required String status, Comment? comment, @JsonKey.new(name: 'comment_view') CommentView? commentView, @JsonKey.new(name: 'comment_id') int? commentId, Community? community, PostView? post, @JsonKey.new(name: 'post_id') int? postId})
-
constfactory
-
UserNotificationItemView.fromJson(Map<
String, dynamic> json) -
factory
Properties
-
no setterinherited
- comment → Comment?
-
no setterinherited
- commentId → int?
-
no setterinherited
- commentView → CommentView?
-
no setterinherited
- community → Community?
-
no setterinherited
-
copyWith
→ $UserNotificationItemViewCopyWith<
UserNotificationItemView> -
Create a copy of UserNotificationItemView
with the given fields replaced by the non-null parameter values.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- notifBody → String
-
no setterinherited
- notifId → int
-
no setterinherited
- notifSubtype → String
-
no setterinherited
- notifType → int
-
no setterinherited
- post → PostView?
-
no setterinherited
- postId → int?
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status → String
-
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serializes this UserNotificationItemView to a JSON map.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited