UserRegistrationResponse class
- Annotations
-
- @freezed
Constructors
- UserRegistrationResponse({String? jwt, @JsonKey.new(name: 'registration_created') bool? registrationCreated, @JsonKey.new(name: 'verify_email_sent') bool? verifyEmailSent})
-
constfactory
-
UserRegistrationResponse.fromJson(Map<
String, dynamic> json) -
factory
Properties
-
copyWith
→ $UserRegistrationResponseCopyWith<
UserRegistrationResponse> -
Create a copy of UserRegistrationResponse
with the given fields replaced by the non-null parameter values.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- jwt → String?
-
no setterinherited
- registrationCreated → bool?
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- verifyEmailSent → bool?
-
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serializes this UserRegistrationResponse to a JSON map.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited