UserSubscribeResponse class

Annotations
  • @freezed

Constructors

UserSubscribeResponse({@JsonKey.new(name: 'person_view') PersonView? personView, bool? subscribed})
const
factory
UserSubscribeResponse.fromJson(Map<String, dynamic> json)
factory

Properties

copyWith → $UserSubscribeResponseCopyWith<UserSubscribeResponse>
Create a copy of UserSubscribeResponse with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
personView PersonView?
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subscribed bool?
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this UserSubscribeResponse to a JSON map.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited